@@ -19,8 +19,8 @@
  *
  */
 
-#ifndef FBMODEL_FBCALENDAR_H
-#define FBMODEL_FBCALENDAR_H
+#ifndef FREEBUSYCALENDAR_H
+#define FREEBUSYCALENDAR_H
 
 #include "calendarsupport_export.h"
 
@@ -29,14 +29,13 @@
 #include <KCalCore/Calendar>
 #include <KCalCore/Event>
 
-namespace CalendarSupport
-{
+namespace CalendarSupport {
 class FreeBusyCalendarPrivate;
 class CALENDARSUPPORT_EXPORT FreeBusyCalendar : public QObject
 {
     Q_OBJECT
 public:
-    explicit FreeBusyCalendar(QObject *parent = Q_NULLPTR);
+    explicit FreeBusyCalendar(QObject *parent = nullptr);
 
     virtual ~FreeBusyCalendar();
 
@@ -52,6 +51,5 @@ private:
     void deleteAllEvents();
     FreeBusyCalendarPrivate *const d;
 };
-
 }
-#endif // FBMODEL_FBCALENDAR_H
+#endif // FREEBUSYCALENDAR_H
